package com.ruoyi.project.patrol.dev.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.patrol.dev.mapper.TDevPagaMapper;
import com.ruoyi.project.patrol.dev.domain.TDevPaga;
import com.ruoyi.project.patrol.dev.service.ITDevPagaService;

/**
 * PAGAService业务层处理
 * 
 * @author admin
 * @date 2023-11-02
 */
@Service
public class TDevPagaServiceImpl implements ITDevPagaService 
{
    @Autowired
    private TDevPagaMapper tDevPagaMapper;

    /**
     * 查询PAGA
     * 
     * @param id PAGA主键
     * @return PAGA
     */
    @Override
    public TDevPaga selectTDevPagaById(Long id)
    {
        return tDevPagaMapper.selectTDevPagaById(id);
    }

    /**
     * 查询PAGA列表
     * 
     * @param tDevPaga PAGA
     * @return PAGA
     */
    @Override
    public List<TDevPaga> selectTDevPagaList(TDevPaga tDevPaga)
    {
        return tDevPagaMapper.selectTDevPagaList(tDevPaga);
    }

    /**
     * 新增PAGA
     * 
     * @param tDevPaga PAGA
     * @return 结果
     */
    @Override
    public int insertTDevPaga(TDevPaga tDevPaga)
    {
        return tDevPagaMapper.insertTDevPaga(tDevPaga);
    }

    /**
     * 修改PAGA
     * 
     * @param tDevPaga PAGA
     * @return 结果
     */
    @Override
    public int updateTDevPaga(TDevPaga tDevPaga)
    {
        return tDevPagaMapper.updateTDevPaga(tDevPaga);
    }

    /**
     * 批量删除PAGA
     * 
     * @param ids 需要删除的PAGA主键
     * @return 结果
     */
    @Override
    public int deleteTDevPagaByIds(Long[] ids)
    {
        return tDevPagaMapper.deleteTDevPagaByIds(ids);
    }

    /**
     * 删除PAGA信息
     * 
     * @param id PAGA主键
     * @return 结果
     */
    @Override
    public int deleteTDevPagaById(Long id)
    {
        return tDevPagaMapper.deleteTDevPagaById(id);
    }
}
